# Copyright (C) 2015-2017 XLAB, Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""ofcloud URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.9/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.conf.urls import url, include
    2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
"""
from django.conf.urls import url, include
from django.contrib import admin
from rest_framework import routers

from ofcloud.api import SimulationViewSet, InstanceViewSet
from ofcloud.views import download_instance_case, download_instance_log

router = routers.DefaultRouter()
router.register(r'simulations', SimulationViewSet)
router.register(r'instances', InstanceViewSet)

urlpatterns = [
    url(r'^', include(router.urls)),

    url(r'^instances/(?P<instance_id>[0-9]+)/download/$', download_instance_case, name='download'),
    url(r'^instances/(?P<instance_id>[0-9]+)/log/$', download_instance_log, name='instance-log'),

    url(r'^admin/', admin.site.urls),
]
